/*
 * Licensed Materials - Property of IBM
 * (c) Copyright IBM Corporation 2020, 2022. All Rights Reserved.
 *
 * Note to U.S. Government Users Restricted Rights:
 * Use, duplication or disclosure restricted by GSA ADP Schedule
 * Contract with IBM Corp.
 *
 */
import { SchemaDocumentInstance } from './schema-document-instance';
export declare abstract class SchemaDocumentCache {
    protected type: string;
    /** maps absolute path to a schema file to a cached document instance */
    protected documentsCache: Map<string, SchemaDocumentInstance>;
    /** maps absolute path to a workspace to the absolute path of a schema file */
    protected workspacesMap: Map<string, string>;
    protected constructor(type: string);
    protected addDocument(filePath: string, workspacePath: string, document: SchemaDocumentInstance): void;
    /**
     * Removes a document from the cache.
     * @param filePath absolute path to the schema file
     */
    clearSchemaDocument(filePath: string): void;
    /**
     * Clears the entire document cache.
     * Call when restarting the client and reload all files to cache.
     */
    clearCache(): void;
    protected numberDocsAdded: number;
    protected numberDocsRemoved: number;
    protected numberDocsFound: number;
    /**
     * Report on cache size and stats. Mainly used for testing.
     */
    getCacheStats(): Record<string, unknown>;
    /**
     * Normalization of absolute path names required as VS Code API returns path names
     * with lower case drive letters on Windows, but end users can specify Schema
     * path names with driver letter casing in the way they want. We therefore
     * index the cache on Windows always with all uppercase pathNames.
     * @param {string} absolutePath
     * @returns {string} normalized code and if Window
     * @memberof SchemaDocumentsCache
     */
    protected normalizePath(absolutePath: string): string;
}
