/*
 * Licensed Materials - Property of IBM
 * (c) Copyright IBM Corporation 2020, 2022. All Rights Reserved.
 *
 * Note to U.S. Government Users Restricted Rights:
 * Use, duplication or disclosure restricted by GSA ADP Schedule
 * Contract with IBM Corp.
 *
 */
import * as zapp from '../parser/zapp-schema';
import { ZappProfilesController } from './zapp-profiles-controller';
/**
 * A collection of business logic for accessing, manipulating, validating
 * rse api mappings in ZAPP documents.
 *
 * Conventions used:
 * - load methods are async and load from disk
 * - get methods are sync as they assume zapp is in cache
 * - workspacePath is the path to the zapp file folder; not the absolute path the file
 */
export declare class RseApiController extends ZappProfilesController {
    /**
     * @param {string} workspacePath Path to a folder in which a zapp file can be found
     * @returns {(string[] | undefined)} Returns the list of all the profiles founds in a currently caches ZAPP file
     */
    static getRseApiProfileNames(workspacePath: string): string[] | undefined;
    /**
     * Validation check to test if a ZAPP file only contains only one Mappings profile
     *
     * @param {string} workspacePath Path to a folder in which a zapp file can be found
     * @returns {boolean} True if one entry was found
     */
    static onlyOneMappingsEntry(workspacePath: string): boolean;
    /**
     * Requires that the ZAPP file was already cached. If in doubt call loadRseApiSettings()
     *
     * @param {string} workspacePath Path to a folder in which a zapp file can be found
     * @returns {(zapp.RseapiSettingsItem | undefined)} Returns the settings specified for an RSE API profile
     */
    static getRseApiSettings(workspacePath: string): zapp.RseapiSettingsItem | undefined;
    /**
     * Loads a ZAPP file from the specified path and return RSE API settings.
     *
     * @param {string} workspacePath Path to a folder in which a zapp file can be found
     * @returns {(Promise<zapp.RseapiSettingsItem | undefined>)} Returns the settings specified for an RSE API profile
     */
    static loadRseApiSettings(workspacePath: string): Promise<zapp.RseapiSettingsItem | undefined>;
}
