/*
 * Licensed Materials - Property of IBM
 * (c) Copyright IBM Corporation 2020, 2022. All Rights Reserved.
 *
 * Note to U.S. Government Users Restricted Rights:
 * Use, duplication or disclosure restricted by GSA ADP Schedule
 * Contract with IBM Corp.
 *
 */
import * as zapp from '../parser/zapp-schema';
/**
 * A collection of business logic for accessing, manipulating, validating
 * user build data in ZAPP documents.
 *
 * Conventions used:
 * - load methods are async and load from disk
 * - get methods are sync as they assume zapp is in cache
 * - workspacePath is the path to the zapp file folder; not the absolute path the file
 */
export declare class ZappProfilesController {
    /**
     * Gets all the profiles found in a ZAPP file loaded from the path specified.
     * This call assumes that the ZAPP files was already loaded by the client, i.e.
     * during editor startup or some other asynchronous call to loadZappProfiles().
     *
     * @param {string} workspacePath Path to a folder in which a zapp file can be found
     * @returns {(zapp.Profile[] | undefined)}
     */
    static getZappProfiles(workspacePath: string): zapp.Profile[] | undefined;
    /**
     * Loads a ZAPP file from the path specified and returns all the profiles found in the doc.
     *
     * @param {string} workspacePath Path to a folder in which a zapp file can be found
     * @returns {(Promise<zapp.Profile[] | undefined>)}
     */
    static loadZappProfiles(workspacePath: string): Promise<zapp.Profile[] | undefined>;
}
