/*
 * Licensed Materials - Property of IBM
 * (c) Copyright IBM Corporation 2020, 2022. All Rights Reserved.
 *
 * Note to U.S. Government Users Restricted Rights:
 * Use, duplication or disclosure restricted by GSA ADP Schedule
 * Contract with IBM Corp.
 *
 */
import { ZappDocumentInstance } from './zapp-document-instance';
import { SchemaDocumentCache } from '../../schemas/parser/schema-documents-cache';
/**
 * Class that finds, loads, and caches instances of zapp files in memory.
 */
export declare class ZappDocumentsCache extends SchemaDocumentCache {
    static cacheType: string;
    private static instance;
    protected static getInstance(): ZappDocumentsCache;
    protected static resetInstance(): void;
    /**
     * Retrieves a zapp file from the cache. Although  the file to retrieve is provided to
     * identify the file, it will not load it into the cache if not found to keep access to the
     * cache synchronous. Undefined will return, which could then be used to call loadZappDocument()
     * to load it an place it in the cache.
     * @param filePath absolute path to the zapp file
     * @returns {(Promise<ZappDocumentInstance | undefined>)} undefined if file was not cached, yet
     */
    static getZappDocument(filePath: string): ZappDocumentInstance | undefined;
    /**
     * Asynchronously loads a zapp file from the path provided.
     * @param {string} filePath absolute path to the zapp file
     * @returns {(Promise<ZappDocumentInstance | undefined>)} undefined if invalid path was provided.
     *          In case of loading errors ZappDocumentInstance will contain error messages.
     */
    static loadZappDocument(filePath: string, workspacePath: string): Promise<ZappDocumentInstance | undefined>;
    /**
     * Removes a document from the cache.
     * @param filePath absolute path to the zapp file
     */
    static clearZappDocument(filePath: string): void;
    /**
     * Gets the cached ZAPP document for the workspace path provided.
     * Assumes that the document cache has been updated with the latest file, e.g. by a watcher.
     * @param workspacePath absolute path to the workspace that contains a zapp file
     * @returns {ZappDocumentInstance | undefined} undefined if invalid path was provided.
     */
    static getZappDocumentInWorkspace(workspacePath: string): ZappDocumentInstance | undefined;
    /**
     * Looks for a ZAPP file with various file extensions in the workspace directory and
     * loads the best match into the cache.
     * @param {string} workspacePath path to the workspace in which a zapp file resides
     * @returns {(Promise<ZappDocumentInstance | undefined>)} undefined if invalid path was provided.
     *          In case of loading errors ZappDocumentInstance will contain error messages.
     */
    static loadZappDocumentInWorkspace(workspacePath: string): Promise<ZappDocumentInstance | undefined>;
    static getCacheStats(): Record<string, unknown>;
    static clearCache(): void;
}
