/*
 * Licensed Materials - Property of IBM
 * (c) Copyright IBM Corporation 2020, 2022. All Rights Reserved.
 *
 * Note to U.S. Government Users Restricted Rights:
 * Use, duplication or disclosure restricted by GSA ADP Schedule
 * Contract with IBM Corp.
 *
 */
import * as zCodeFormat from '../parser/zcodeformat-schema';
/**
 * A collection of business logic for accessing, manipulating, validating
 * user build data in ZCodeFormat documents.
 *
 * Conventions used:
 * - load methods are async and load from disk
 * - get methods are sync as they assume zCodeFormat is in cache
 * - workspacePath is the path to the zCodeFormat file folder; not the absolute path the file
 */
export declare class ZCodeFormatController {
    /**
     * Gets all the formatting found in a ZCodeFormat file loaded from the path specified.
     * This call assumes that the ZCodeFormat files was already loaded by the client, i.e.
     * during editor startup or some other asynchronous call to loadZCodeFormatProfiles().
     *
     * @param {string} workspacePath Path to a folder in which a zCodeFormat file can be found
     * @returns {(zCodeFormat.ZCodeFormatSettings | undefined)}
     */
    static getZCodeFormattingDocument(workspacePath: string): zCodeFormat.ZCodeFormatSettings | undefined;
    /**
     * Loads a ZCodeFormat file from the path specified and returns all the formatting found in the doc.
     *
     * @param {string} workspacePath Path to a folder in which a zCodeFormat file can be found
     * @returns {(Promise<zCodeFormat.Profile[] | undefined>)}
     */
    static loadZCodeFormattingDocument(workspacePath: string): Promise<zCodeFormat.ZCodeFormatSettings | undefined>;
}
