/*
 * Licensed Materials - Property of IBM
 * (c) Copyright IBM Corporation 2020, 2022. All Rights Reserved.
 *
 * Note to U.S. Government Users Restricted Rights:
 * Use, duplication or disclosure restricted by GSA ADP Schedule
 * Contract with IBM Corp.
 *
 */
import { ZCodeFormatDocumentInstance } from './zcodeformat-document-instance';
import { SchemaDocumentCache } from '../../schemas/parser/schema-documents-cache';
/**
 * Class that finds, loads, and caches instances of zCodeFormat files in memory.
 */
export declare class ZCodeFormatDocumentsCache extends SchemaDocumentCache {
    static cacheType: string;
    private static instance;
    protected static getInstance(): ZCodeFormatDocumentsCache;
    protected static resetInstance(): void;
    /**
     * Retrieves a zCodeFormat file from the cache. Although  the file to retrieve is provided to
     * identify the file, it will not load it into the cache if not found to keep access to the
     * cache synchronous. Undefined will return, which could then be used to call loadZCodeFormatDocument()
     * to load it an place it in the cache.
     * @param filePath absolute path to the zCodeFormat file
     * @returns {(Promise<ZCodeFormatDocumentInstance | undefined>)} undefined if file was not cached, yet
     */
    static getZCodeFormatDocument(filePath: string): ZCodeFormatDocumentInstance | undefined;
    /**
     * Asynchronously loads a zCodeFormat file from the path provided.
     * @param {string} filePath absolute path to the zCodeFormat file
     * @returns {(Promise<ZCodeFormatDocumentInstance | undefined>)} undefined if invalid path was provided.
     *          In case of loading errors ZCodeFormatDocumentInstance will contain error messages.
     */
    static loadZCodeFormatDocument(filePath: string, workspacePath: string): Promise<ZCodeFormatDocumentInstance | undefined>;
    /**
     * Removes a document from the cache.
     * @param filePath absolute path to the zapp file
     */
    static clearZCodeFormatDocument(filePath: string): void;
    /**
     * Gets the cached ZCodeFormat document for the workspace path provided.
     * Assumes that the document cache has been updated with the latest file, e.g. by a watcher.
     * @param workspacePath absolute path to the workspace that contains a zCodeFormat file
     * @returns {ZCodeFormatDocumentInstance | undefined} undefined if invalid path was provided.
     */
    static getZCodeFormatDocumentInWorkspace(workspacePath: string): ZCodeFormatDocumentInstance | undefined;
    /**
     * Looks for a ZCodeFormat file with various file extensions in the workspace directory and
     * loads the best match into the cache.
     * @param {string} workspacePath path to the workspace in which a zCodeFormat file resides
     * @returns {(Promise<ZCodeFormatDocumentInstance | undefined>)} undefined if invalid path was provided.
     *          In case of loading errors ZCodeFormatDocumentInstance will contain error messages.
     */
    static loadZCodeFormatDocumentInWorkspace(workspacePath: string): Promise<ZCodeFormatDocumentInstance | undefined>;
    static getCacheStats(): Record<string, unknown>;
    static clearCache(): void;
}
