/*
 * Licensed Materials - Property of IBM
 * (c) Copyright IBM Corporation 2020, 2022. All Rights Reserved.
 *
 * Note to U.S. Government Users Restricted Rights:
 * Use, duplication or disclosure restricted by GSA ADP Schedule
 * Contract with IBM Corp.
 *
 */
export declare type ProcDivIndent = {
    indentForAllBlocks?: number;
    blocks?: {};
    [k: string]: unknown;
} | {
    indentForAllBlocks?: false;
    blocks?: BlockIndent;
    [k: string]: unknown;
};
/**
 * A collection of formatting preferences that can be traded between IBM zApplications
 */
export interface ZCodeFormatSettings {
    additionalProperties?: false;
    cobol?: Cobol;
    copybook?: Copybook;
    [k: string]: unknown;
}
export interface Cobol {
    dataDivision?: {
        enableIndentation?: false;
        indentation?: {};
        [k: string]: unknown;
    } | {
        enableIndentation?: true;
        indentation?: DataDivIndent;
        [k: string]: unknown;
    };
    procedureDivision?: {
        enableIndentation?: false;
        indentation?: {};
        [k: string]: unknown;
    } | {
        enableIndentation?: true;
        indentation?: ProcDivIndent;
        [k: string]: unknown;
    };
    /**
     * Reserved words
     */
    reservedWordCase?: 'none' | 'upper' | 'lower' | 'mixed';
    /**
     * User-defined words
     */
    userDefinedWordCase?: 'none' | 'upper' | 'lower' | 'mixed';
    /**
     * Comment
     */
    commentCase?: 'none' | 'upper' | 'lower' | 'mixed';
    /**
     * Function
     */
    functionCase?: 'none' | 'upper' | 'lower' | 'mixed';
    /**
     * Date format
     */
    dateFormatCase?: 'none' | 'upper' | 'lower' | 'mixed';
    /**
     * Compiler directive
     */
    compilerDirectiveCase?: 'none' | 'upper' | 'lower' | 'mixed';
    /**
     * End of Area B
     *
     * If -1, will use Margin R as the end of Area B
     */
    endOfAreaB?: number & {
        [k: string]: unknown;
    };
    /**
     * If indentation moves code beyond Area B
     */
    lineWrappingStyle?: 'wrapToNextLine' | 'noIndent' | 'indentToAreaB' | 'indentPastAreaB';
}
export interface DataDivIndent {
    /**
     * Start of Area A
     * Cannot be used if enableIndentation is false
     */
    startOfAreaA?: number;
    /**
     * Indent Length
     * Cannot be used if enableIndentation is false
     */
    indentLength?: number;
}
export interface BlockIndent {
    /**
     * Indent length of AT END block
     * Cannot be used if enableIndentation is false
     * Cannot be used if indentForAllBlocks is used
     */
    indentAtEndBlock?: number;
    /**
     * Indent length of AT END OF PAGE block
     * Cannot be used if enableIndentation is false
     * Cannot be used if indentForAllBlocks is used
     */
    indentAtEndOfPageBlock?: number;
    /**
     * Indent length of EXEC block
     * Cannot be used if enableIndentation is false
     * Cannot be used if indentForAllBlocks is used
     */
    indentExecBlock?: number;
    /**
     * Indent END-EXEC phrase
     * Cannot be used if enableIndentation is false
     * END-EXEC phrase will be indented with Exec Block
     */
    indentEndExecPhrase?: boolean;
    /**
     * Indent length of IF block
     * Cannot be used if enableIndentation is false
     * Cannot be used if indentForAllBlocks is used
     */
    indentIfBlock?: number;
    /**
     * Indent length of INVALID KEY block
     * Cannot be used if enableIndentation is false
     * Cannot be used if indentForAllBlocks is used
     */
    indentInvalidKeyBlock?: number;
    /**
     * Indent length of NOT AT END block
     * Cannot be used if enableIndentation is false
     * Cannot be used if indentForAllBlocks is used
     */
    indentNotAtEndBlock?: number;
    /**
     * Indent length of NOT AT END OF PAGE block
     * Cannot be used if enableIndentation is false
     * Cannot be used if indentForAllBlocks is used
     */
    indentNotAtEndOfPageBlock?: number;
    /**
     * Indent length of INVALID KEY
     * Cannot be used if enableIndentation is false
     * Cannot be used if indentForAllBlocks is used
     */
    indentNotInvalidKeyBlock?: number;
    /**
     * Indent length of NOT ON EXCEPTION block
     * Cannot be used if enableIndentation is false
     * Cannot be used if indentForAllBlocks is used
     */
    indentNotOnExceptionBlock?: number;
    /**
     * Indent length of NOT ON OVERFLOW block
     * Cannot be used if enableIndentation is false
     * Cannot be used if indentForAllBlocks is used
     */
    indentNotOnOverflowBlock?: number;
    /**
     * Indent length of NOT ON SIZE ERROR block
     * Cannot be used if enableIndentation is false
     * Cannot be used if indentForAllBlocks is used
     */
    indentNotOnSizeErrorBlock?: number;
    /**
     * Indent length of ON EXCEPTION block
     * Cannot be used if enableIndentation is false
     * Cannot be used if indentForAllBlocks is used
     */
    indentOnExceptionBlock?: number;
    /**
     * Indent length of ON OVERFLOW block
     * Cannot be used if enableIndentation is false
     * Cannot be used if indentForAllBlocks is used
     */
    indentOnOverflowBlock?: number;
    /**
     * Indent length of ON SIZE ERROR block
     * Cannot be used if enableIndentation is false
     * Cannot be used if indentForAllBlocks is used
     */
    indentOnSizeErrorBlock?: number;
    /**
     * Indent length of PERFORM block
     * Cannot be used if enableIndentation is false
     * Cannot be used if indentForAllBlocks is used
     */
    indentPerformBlock?: number;
    /**
     * Indent length of WHEN block
     * Cannot be used if enableIndentation is false
     * Cannot be used if indentForAllBlocks is used
     */
    indentWhenBlock?: number;
}
export interface Copybook {
    /**
     * Format copybook code in uppercase
     */
    codeCase?: 'upper' | 'lower';
    /**
     * Format copybook comments in uppercase
     */
    commentCase?: 'upper' | 'lower';
}
